summaryrefslogtreecommitdiff
path: root/web/taginfo.rb
diff options
context:
space:
mode:
authorJochen Topf <jochen@topf.org>2013-01-14 19:53:21 +0100
committerJochen Topf <jochen@topf.org>2013-01-14 19:53:21 +0100
commit9f39838e8ad5b6b1dda21013152055f8a008acc9 (patch)
tree7a30495cee48c7b103e7a8f5ba71f34bbbf65dc6 /web/taginfo.rb
parent4298e373d2c7ebbd8e2c82dda6cff54f6c3995b0 (diff)
downloadtaginfo-9f39838e8ad5b6b1dda21013152055f8a008acc9.tar
taginfo-9f39838e8ad5b6b1dda21013152055f8a008acc9.tar.gz
Add new relations section
There is a whole new relations section which gives information about different relation types. There is a list of all relation types and there is a page for each relation type which currently contains an empty overview tab and a roles tab with a list of roles used with this relation type. There is currently no link that leads to this section as it is not finished yet.
Diffstat (limited to 'web/taginfo.rb')
-rwxr-xr-xweb/taginfo.rb7
1 files changed, 5 insertions, 2 deletions
diff --git a/web/taginfo.rb b/web/taginfo.rb
index ab6a96e..d686174 100755
--- a/web/taginfo.rb
+++ b/web/taginfo.rb
@@ -156,9 +156,9 @@ class Taginfo < Sinatra::Base
#-------------------------------------
%w(about download keys sources tags).each do |page|
get '/' + page do
- @title = (page =~ /^(keys|tags)$/) ? t.osm[page] : t.taginfo[page]
+ @title = (page =~ /^(keys|tags|relations)$/) ? t.osm[page] : t.taginfo[page]
if File.exists?("viewsjs/#{ page }.js.erb")
javascript "#{ r18n.locale.code }/#{ page }"
end
@@ -190,6 +190,8 @@ class Taginfo < Sinatra::Base
load 'lib/api/v4/key.rb'
load 'lib/api/v4/keys.rb'
# load 'lib/api/v4/langtag.rb'
+ load 'lib/api/v4/relation.rb'
+ load 'lib/api/v4/relations.rb'
load 'lib/api/v4/search.rb'
load 'lib/api/v4/site.rb'
load 'lib/api/v4/tag.rb'
@@ -198,6 +200,7 @@ class Taginfo < Sinatra::Base
load 'lib/ui/embed.rb'
load 'lib/ui/keys_tags.rb'
+ load 'lib/ui/relation.rb'
load 'lib/ui/reports.rb'
load 'lib/ui/search.rb'
load 'lib/ui/taginfo.rb'
@@ -156,9 +156,9 @@ class Taginfo < Sinatra::Base
#-------------------------------------
- %w(about download keys sources tags).each do |page|
+ %w(about download keys relations sources tags).each do |page|
get '/' + page do